==> wiki3_4_3.zip: wiki3_4_3/plugin/search/SearchHandler.pm <==
############################################################
# 
# եɽޤ
# <pre>
# {{search}}
# </pre>
# ɥСɽvץĤƤ
# <pre>
# {{search v}}
# </pre>
# 
############################################################
package plugin::search::SearchHandler;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	my $word = Util::trim($cgi->param("word"));
	
	my $buf = "";
	
	$wiki->set_title("");
	$buf .= "<form method=\"GET\" action=\"".$wiki->config('script_name')."\">\n".
	        " <input type=\"text\" name=\"word\" size=\"20\" value=\"".$cgi->escapeHTML($word)."\"> ";
	
	if($cgi->param("t") eq "or"){
		$buf .= "<input type=\"radio\" name=\"t\" value=\"and\"> AND ";
		$buf .= "<input type=\"radio\" name=\"t\" value=\"or\" checked> OR ";
	} else {
		$buf .= "<input type=\"radio\" name=\"t\" value=\"and\" checked> AND ";
		$buf .= "<input type=\"radio\" name=\"t\" value=\"or\"> OR ";
	}
	
	$buf .=  "<input type=\"submit\" value=\"   \">".
	         "<input type=\"hidden\" name=\"action\" value=\"SEARCH\">".
	         "</form>\n";
	
	#---------------------------------------------------------------------------
	# ¹
	if($word ne ""){
		my @list = $wiki->get_page_list;
		my @words = split(/ |/,$word);
		my $name;
		$buf = $buf."<ul>\n";
		foreach $name (@list){
			my $page = $wiki->get_page($name);
			if($cgi->param("t") eq "or"){
				# OR -------------------------------------------------------
				foreach(@words){
					if($_ eq ""){ next; }
					my $index = index($page,$_);
					if($index!=-1){
						$buf .= "<li><a href=\"".$wiki->config('script_name')."?page=".Util::url_encode($name)."\">".
						        $cgi->escapeHTML($name)."</a> - ".Util::escapeHTML(&get_match_content($page,$index))."</li>\n";
						last;
					}
				}
			} else {
				# AND ------------------------------------------------------
				my $flag = 1;
				my $index;
				foreach(@words){
					if($_ eq ""){ next; }
					$index = index($page,$_);
					if($index==-1){
						$flag = 0;
						last;
					}
				}
				if($flag == 1){
					$buf .= "<li><a href=\"".$wiki->config('script_name')."?page=".Util::url_encode($name)."\">".
					        $cgi->escapeHTML($name)."</a> - ".Util::escapeHTML(&get_match_content($page,$index))."</li>\n";
				}
			}
		}
		$buf = $buf."</ul>\n";
	}
	return $buf;
}

#===========================================================
# ˥ޥåԤФؿ
#===========================================================
sub get_match_content {
	my $content = shift;
	my $index   = shift;
	my $pre  = substr($content,0,$index);
	my $post = substr($content,$index,length($content)-$index);
	
	my $pre_index  = rindex($pre,"\n");
	if($pre_index==-1){ $pre_index = 0; }
	
	my $post_index = index($post,"\n");
	if($post_index==-1){ $post_index = length($post); }
	$post_index += $index;
	
	return substr($content,$pre_index,$post_index-$pre_index);
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/search/SearchHandler.pm <==
############################################################
# 
# եɽޤ
# <pre>
# {{search}}
# </pre>
# ɥСɽvץĤƤ
# <pre>
# {{search v}}
# </pre>
# 
############################################################
package plugin::search::SearchHandler;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	my $word = Util::trim($cgi->param("word"));
	
	my $buf = "";
	
	$wiki->set_title("");
	$buf .= "<form method=\"GET\" action=\"".$wiki->config('script_name')."\">\n".
	        " <input type=\"text\" name=\"word\" size=\"20\" value=\"".$cgi->escapeHTML($word)."\"> ";
	
	if($cgi->param("t") eq "or"){
		$buf .= "<input type=\"radio\" name=\"t\" value=\"and\"> AND ";
		$buf .= "<input type=\"radio\" name=\"t\" value=\"or\" checked> OR ";
	} else {
		$buf .= "<input type=\"radio\" name=\"t\" value=\"and\" checked> AND ";
		$buf .= "<input type=\"radio\" name=\"t\" value=\"or\"> OR ";
	}
	
	$buf .=  "<input type=\"submit\" value=\"   \">".
	         "<input type=\"hidden\" name=\"action\" value=\"SEARCH\">".
	         "</form>\n";
	
	#---------------------------------------------------------------------------
	# ¹
	if($word ne ""){
		my @list = $wiki->get_page_list();
		my @words = split(/ |/,$word);
		my $name;
		$buf = $buf."<ul>\n";
		foreach $name (@list){
			my $page = $name."\n".$wiki->get_page($name);
			if($cgi->param("t") eq "or"){
				# OR -------------------------------------------------------
				foreach(@words){
					if($_ eq ""){ next; }
					my $index = index($page,$_);
					if($index!=-1){
						$buf .= "<li><a href=\"".$wiki->config('script_name').
						        "?page=".Util::url_encode($name)."\">".
						        $cgi->escapeHTML($name)."</a> - ".
						        Util::escapeHTML(&get_match_content($wiki,$name,$page,$index))."</li>\n";
						last;
					}
				}
			} else {
				# AND ------------------------------------------------------
				my $flag = 1;
				my $index;
				foreach(@words){
					if($_ eq ""){ next; }
					$index = index($page,$_);
					if($index==-1){
						$flag = 0;
						last;
					}
				}
				if($flag == 1){
					$buf .= "<li><a href=\"".$wiki->config('script_name').
					        "?page=".Util::url_encode($name)."\">".
					        $cgi->escapeHTML($name)."</a> - ".
					        Util::escapeHTML(&get_match_content($wiki,$name,$page,$index))."</li>\n";
				}
			}
		}
		$buf = $buf."</ul>\n";
	}
	return $buf;
}

#===========================================================
# ˥ޥåԤФؿ
#===========================================================
sub get_match_content {
	my $wiki    = shift;
	my $name    = shift;
	my $content = shift;
	my $index   = shift;
	
	unless($wiki->can_show($name)){
		return "ȸ¤ޤ";
	}
	my $pre  = substr($content,0,$index);
	my $post = substr($content,$index,length($content)-$index);
	
	my $pre_index  = rindex($pre,"\n");
	if($pre_index==-1){ $pre_index = 0; }
	
	my $post_index = index($post,"\n");
	if($post_index==-1){ $post_index = length($post); }
	$post_index += $index;
	
	return substr($content,$pre_index,$post_index-$pre_index);
}

1;
